@@ -67,11 +67,12 @@ NULL
 ##' functions.
 ##' @param x A numeric or character variable
 ##' @param n The maximum number of values that may be returned.
+##' @param pct Default = TRUE. Include percentage of responses within each category
 ##' @return A named vector.
 ##' @export
 ##' @author Paul E. Johnson <pauljohn@@ku.edu>
 cutByTable <-
-    function(x, n = 5)
+    function(x, n = 5, pct = TRUE)
 {
     table1 <- table(x)
     n <- min(n, length(names(table1)))
@@ -85,8 +86,12 @@ cutByTable <-
     } else {
         tabNames
     }
-    freq <- 100*round(table1cut/sum(table1),1)
-    names(res) <- paste(tabNames," (",freq,"%)", sep="")
+    if (pct) {
+        freq <- 100*round(table1cut/sum(table1), 2)
+        names(res) <- paste(tabNames," (",freq,"%)", sep="")
+    } else {
+        names(res) <- tabNames
+    }
     if (is.factor(x)) res <- factor(res, levels = levels(x))
     res
 }
@@ -107,6 +112,7 @@ NULL
 ##' @param n The number of quantile points. See details.
 ##' @return A vector
 ##' @export
+##' @importFrom stats quantile
 ##' @author Paul E. Johnson <pauljohn@@ku.edu>
 cutByQuantile <-
     function(x, n = 3)
@@ -152,6 +158,7 @@ cutByQuantile <-
 ##' values that divide the data at c(m-sd, m, m+sd) are returned. If n
 ##' > 4, the returned values are c(m-2sd, m-sd, m, m+sd, m+2sd).
 ##' @export
+##' @importFrom stats sd
 ##' @examples
 ##' x <- rnorm(100, m = 100, s = 20)
 ##' cutBySD (x, n = 3)
@@ -251,6 +258,8 @@ NULL
 ##' "table", or "seq") or a user-supplied function that can receive
 ##' x and return a selection of values.
 ##' @param n Number of values to be selected.
+##' @param pct Default TRUE. Include percentage of observed cases
+##' in variable name? (used in legends)
 ##' @return A named vector of values.
 ##' @export
 ##' @method getFocal default
@@ -264,7 +273,7 @@ NULL
 ##' getFocal(x, xvals = "std.dev", n = 5)
 ##' getFocal(x, xvals = c(-1000, 0.2, 0,5))
 ##'
-getFocal.default <- function(x, xvals = NULL, n = 3, ...)
+getFocal.default <- function(x, xvals = NULL, n = 3, pct = TRUE, ...)
 {
     xRange <- magRange(range(x, na.rm = TRUE), 1.1)
 
@@ -283,7 +292,7 @@ getFocal.default <- function(x, xvals = NULL, n = 3, ...)
         xvals <- match.arg(tolower(xvals),
                            c("quantile", "std.dev.","table", "seq"))
         xfocal <- switch(xvals,
-                         table = cutByTable(x, n),
+                         table = cutByTable(x, n, pct = pct),
                          quantile = cutByQuantile(x, n),
                          "std.dev." = cutBySD(x, n),
                          seq = plotSeq(x, n),
@@ -308,13 +317,13 @@ NULL
 ##' getFocal(x)
 ##' getFocal(x, n = 2)
 ##'
-getFocal.factor <- function(x, xvals = NULL, n = 3, ...)
+getFocal.factor <- function(x, xvals = NULL, n = 3, pct = TRUE, ...)
 {
     if (is.null(xvals)) {
-        xvals <- cutByTable(x, n)
+        xvals <- cutByTable(x, n, pct = pct)
         return(xvals)
     }
-   if (is.vector(xvals)) {
+    if (is.vector(xvals)) {
        x <- factor(x) ## drop unused levels
        if (!all(xvals %in% levels(x))) stop("xvals includes non-observed levels of x")
        return(xvals)
@@ -341,6 +350,37 @@ getFocal.factor <- function(x, xvals = NULL, n = 3, ...)
 }
 
 
+##' @export
+##' @method getFocal character
+##' @rdname getFocal
+##' @examples
+##' x <- c("A","B","A","B","C","D","D","D")
+##' getFocal(x)
+##' getFocal(x, n = 2)
+##'
+getFocal.character <- function(x, xvals = NULL, n = 3, pct = TRUE, ...)
+{
+    if (is.null(xvals)) {
+        xvals <- cutByTable(x, n, pct = pct)
+        return(xvals)
+    }
+    if (is.vector(xvals)) {
+       if (!all(xvals %in% unique(x))) stop("xvals includes non-observed values of x")
+       return(xvals)
+    }
+    if (is.function(xvals)) {
+        xvals <- xvals(x, n, ...)
+        return(xvals)
+    }
+
+    xvals <- match.arg(tolower(xvals),
+                       c("table"))
+    xvals <- switch(xvals,
+                    table = cutByTable(x, n, pct = pct),
+                    stop("Sorry, only known algorithm for character variables is 'table'"))
+    xvals
+}
+
 
 
 ##' Pad with 0's.
@@ -384,3 +424,47 @@ checkIntFormat <- function(s) {
     s <- sub("%[#0 ,+-]*[0-9.]*[diouxX]", "", s)
     length(grep("%", s)) == 0L
 }
+
+
+##' Create a uniquely named directory. Appends number & optionally date to directory
+##' name.
+##' 
+##' Checks if the requested directory exists. If so, will create new directory
+##' name. My favorite method is to have the target directory with a date-based
+##' subdirectory, but set usedate as FALSE if you don't like that. Arguments
+##' showWarnings, recursive, and mode are passed along to R's dir.create, which
+##' does the actual work here.
+##'
+##' Default response to dir = "../output/" fixes the directory name like this,
+##' "../output/20151118-1/" because usedate is assumed TRUE. If usedate = FALSE,
+##' then output names will be like "../output-1/", "../output-2/", and so forth.
+##' @param path A character string for the base name of the directory.
+##' @param usedate TRUE or FALSE: Insert YYYYMMDD information?
+##' @param showWarnings default TRUE. Show warnings? Will be passed on to dir.create
+##' @param recursive default TRUE. Will be passed on to dir.create
+##' @param mode  Default permissions on unix-alike systems. Will be passed on to dir.create
+##' @export
+##' @return a character string with the directory name
+##' @author Paul E Johnson <pauljohn@@ku.edu>
+dir.create.unique <- function(path, usedate = TRUE,
+                              showWarnings = TRUE,
+                              recursive = TRUE,
+                              mode = "0777"){
+    dts <- function(name) gsub("/$", "", name)
+    if (!file.exists(dts(path))){
+        dir.create(path, recursive = recursive, showWarnings = showWarnings, mode = mode)
+        return(path)
+    } else {
+        today <- format(Sys.time(), "%Y%m%d")
+        j <- 1
+        ocandidate <- paste0(dts(path), ifelse(usedate, paste0("/", today), ""), "-",  j, "/")
+        while (file.exists(dts(ocandidate))) {
+            j <- j + 1
+            ocandidate <- paste0(dts(path), ifelse(usedate, paste0("/", today), ""), "-",  j, "/")
+        }
+        path <- ocandidate
+        dir.create(path, recursive = recursive, showWarnings = showWarnings, mode = mode)
+        return(path)
+    }
+}
+
